@@ -8,7 +8,6 @@ Attribution-NonCommercial-NoDerivs 2.0 UK: England & Wales License.
 """
 
 # system imports
-from __future__ import division, print_function, absolute_import
 import sys
 import os
 import platform
@@ -17,13 +16,12 @@ import pkg_resources as pkgr
 import time
 import numpy as np
 import logging
-from qtpy import QtCore, QtWidgets, uic
+from PyQt5 import QtCore, QtWidgets, uic
 from mercuryitc.mercury_driver import MercuryITC_TEMP, MercuryITC_HTR, MercuryITC_AUX
 
 # local imports
 from mercurygui.feed import MercuryFeed
-from mercurygui.connection_dialog import ConnectionDialog
-from mercurygui.pyqt_labutils import LedIndicator
+from mercurygui.pyqt_labutils import LedIndicator, ConnectionDialog
 from mercurygui.pyqtplot_canvas import TemperatureHistoryPlot
 from mercurygui.config.main import CONF
 
@@ -54,7 +52,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         self.labelTitle.setFont(font)
 
         # create popup Widgets
-        self.connectionDialog = ConnectionDialog(self, feed.mercury)
+        self.connectionDialog = ConnectionDialog(self, feed.mercury, CONF)
         self.readingsDialog = None
         self.modulesDialog = None
 
@@ -94,7 +92,8 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         self.set_up_menubar()
 
         # check if mercury is connected, connect slots
-        self.display_message('Looking for Mercury at %s...' % self.feed.visa_address)
+        self.display_message('Looking for temperature controller at %s...' %
+                             self.feed.visa_address)
         if self.feed.mercury.connected:
             self.update_gui_connection(connected=True)
 
@@ -102,9 +101,8 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         # adjust clickable buttons upon connect / disconnect
         self.feed.connected_signal.connect(self.update_gui_connection)
 
-        # get new readings when available, send as out signals
+        # get new readings every second, update UI
         self.feed.new_readings_signal.connect(self.update_text)
-        # update plot when new data arrives
         self.feed.new_readings_signal.connect(self.update_plot)
 
         # set up logging to file
@@ -166,7 +164,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         self.canvas.p0.setXRange(-sv, 0)
         self.canvas.p0.enableAutoRange(x=False, y=True)
 
-    @QtCore.Slot(bool)
+    @QtCore.pyqtSlot(bool)
     def update_gui_connection(self, connected):
         if connected:
             self.display_message('Connection established.')
@@ -213,7 +211,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
     def display_error(self, text):
         self.statusbar.showMessage('%s' % text)
 
-    @QtCore.Slot(object)
+    @QtCore.pyqtSlot(object)
     def update_text(self, readings):
         """
         Parses readings for the MercuryMonitorApp and updates UI accordingly
@@ -244,7 +242,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         is_ramp_enable = readings['TempRampEnable'] == 'ON'
         self.r2_checkbox.setChecked(is_ramp_enable)
 
-    @QtCore.Slot(object)
+    @QtCore.pyqtSlot(object)
     def update_plot(self, readings):
         # append data for plotting
         self.xdata = np.append(self.xdata, time.time())
@@ -332,7 +330,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
 
 # =================== CALLBACKS FOR SETTING CHANGES ===========================
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def change_t_setpoint(self):
         new_t = self.t2_edit.value()
 
@@ -343,12 +341,12 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
             self.display_error('Error: Only temperature setpoints between ' +
                                '3.5 K and 300 K allowed.')
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def change_ramp(self):
         self.feed.temperature.loop_rset = self.r1_edit.value()
         self.display_message('Ramp = %s K/min' % self.r1_edit.value())
 
-    @QtCore.Slot(bool)
+    @QtCore.pyqtSlot(bool)
     def change_ramp_auto(self, checked):
         if checked:
             self.feed.temperature.loop_rena = 'ON'
@@ -357,12 +355,12 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
             self.feed.temperature.loop_rena = 'OFF'
             self.display_message('Ramp is turned OFF')
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def change_flow(self):
         self.feed.temperature.loop_fset = self.gf1_edit.value()
         self.display_message('Gas flow  = %s%%' % self.gf1_edit.value())
 
-    @QtCore.Slot(bool)
+    @QtCore.pyqtSlot(bool)
     def change_flow_auto(self, checked):
         if checked:
             self.feed.temperature.loop_faut = 'ON'
@@ -375,12 +373,12 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
             self.gf1_edit.setReadOnly(False)
             self.gf1_edit.setEnabled(True)
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def change_heater(self):
         self.feed.temperature.loop_hset = self.h1_edit.value()
         self.display_message('Heater power  = %s%%' % self.h1_edit.value())
 
-    @QtCore.Slot(bool)
+    @QtCore.pyqtSlot(bool)
     def change_heater_auto(self, checked):
         if checked:
             self.feed.temperature.loop_enab = 'ON'
@@ -395,7 +393,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
 
 # ========================== CALLBACKS FOR MENU BAR ===========================
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def on_readings_clicked(self):
         # create readings overview window if not present
         if self.readingsDialog is None:
@@ -403,7 +401,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         # show it
         self.readingsDialog.show()
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def on_module_selection_clicked(self):
         # create readings overview window if not present
         if self.modulesDialog is None:
@@ -411,7 +409,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         # show it
         self.modulesDialog.open()
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def on_log_clicked(self):
         """
         Opens directory with log files with current log file selected.
@@ -541,7 +539,7 @@ class ModulesDialog(QtWidgets.QDialog):
     Provides a user dialog to select the modules for the feed.
     """
 
-    accepted = QtCore.Signal(object)
+    accepted = QtCore.pyqtSignal(object)
 
     def __init__(self, mercury_feed, parent=None):
         super(self.__class__, self).__init__(parent=parent)
@@ -574,7 +572,7 @@ class ModulesDialog(QtWidgets.QDialog):
         self.comboBoxTEMP.currentTextChanged.connect(self._on_comboBoxTEMP_textChanged)
         self.buttonBox.accepted.connect(self._on_accept)
 
-    @QtCore.Slot(str)
+    @QtCore.pyqtSlot(str)
     def _on_comboBoxTEMP_textChanged(self, text):
         # update content of heater and gasflow combo boxes
         temp_module = next(m for m in self.modules if m.nick == text)
@@ -582,10 +580,10 @@ class ModulesDialog(QtWidgets.QDialog):
         self.comboBoxHTR.setCurrentText(temp_module.loop_htr)
         self.comboBoxAUX.setCurrentText(temp_module.loop_aux)
 
-    @QtCore.Slot()
+    @QtCore.pyqtSlot()
     def _on_accept(self):
         temp_nick = self.comboBoxTEMP.currentText()
-        self.feed.update_modules(temp_nick)  # updated feed
+        self.feed.select_temp_sensor(temp_nick)  # updated feed
         CONF.set('MercuryFeed', 'temperature_module', temp_nick)  # write to config file
 
 
